@@ -1,10 +1,7 @@
-#line 1 "inc/Module/Install/Scripts.pm - /usr/local/lib/perl5/site_perl/5.8.2/Module/Install/Scripts.pm"
-# $File: //depot/cpan/Module-Install/lib/Module/Install/Scripts.pm $ $Author: autrijus $
-# $Revision: #6 $ $Change: 1781 $ $DateTime: 2003/10/22 17:14:03 $ vim: expandtab shiftwidth=4
-
+#line 1 "inc/Module/Install/Scripts.pm - /usr/local/lib/perl5/site_perl/5.8.7/Module/Install/Scripts.pm"
 package Module::Install::Scripts;
 use Module::Install::Base; @ISA = qw(Module::Install::Base);
-$VERSION = '0.01';
+$VERSION = '0.02';
 use strict;
 use File::Basename ();
 
@@ -29,10 +26,10 @@ sub prompt_script {
 }
 
 sub install_script {
-    my ($self, $script_file) = @_;
+    my $self = shift;
     my $args = $self->makemaker_args;
     my $exe_files = $args->{EXE_FILES} ||= [];
-    push @$exe_files, $script_file;
+    push @$exe_files, @_;
 }
 
 sub _read_script {
